#[repr(u32)]pub enum FlacEncoderState {
Ok = 0,
Uninitialized = 1,
OggError = 2,
VerifyDecoderError = 3,
VerifyMismatchInAudioData = 4,
ClientError = 5,
IoError = 6,
FramingError = 7,
MemoryAllocationError = 8,
}Expand description
State values for a FlacEncoder.
The encoder’s state can be obtained by calling FlacEncoder::state().
If the encoder gets into any other state besides Ok
or Uninitialized, it becomes invalid for encoding and
must be deleted by dropping.
Variants
Ok = 0
The encoder is in the normal OK state and samples can be processed.
Uninitialized = 1
The encoder is in the uninitialized state; one of the
FlacEncoderConfig::init_*()
functions must be called before samples can be processed.
OggError = 2
An error occurred in the underlying Ogg layer.
VerifyDecoderError = 3
An error occurred in the underlying verify stream decoder; check
FlacEncoder::verify_decoder_state().
VerifyMismatchInAudioData = 4
The verify decoder detected a mismatch between the original audio signal and the decoded audio signal.
ClientError = 5
One of the callbacks returned a fatal error.
IoError = 6
An I/O error occurred while opening/reading/writing a file. Check errno.
FramingError = 7
An error occurred while writing the stream; usually, the write_callback returned an error.
MemoryAllocationError = 8
Memory allocation failed.